@@ -3,7 +3,7 @@ import cmath
 '''
 Please don't change the below mentioned values of {errors} and {name}
 without reading the whole code.It might result in code ambiguity.
-##version==0.1.0##
+
 '''
 negative_error ="Side lengths can't be less than or equal to zero"
 no_of_side_error="Number of sides can't be float"
@@ -658,7 +658,7 @@ def findH(g, f):
     
 ###########################################################################################################################################            
 l=['',
-  f'1.    AREA OF TRIANGLE \n Syntax -> {name}.triangle.area(<length>,<bredth>)\n Syntax -> {name}.triangle.area(<side1>,<side2>,<side3>)',
+  f'1.    AREA OF TRIANGLE \n Syntax -> {name}.triangle.area(<height>,<base>)\n Syntax -> {name}.triangle.area(<side1>,<side2>,<side3>)',
   f'2.    PERIMETER OF TRIANGLE \n Syntax -> {name}.triangle.perimeter(<side1>,<side2>,<side3>)',
   f'3.    AREA OF SQUARE \n Syntax -> {name}.square.area(<side>)',
   f'4.    PERIMETER OF SQUARE \n Syntax -> {name}.square.perimeter(<side>)',
